@@ -8,6 +8,9 @@ class DuelPlayer(User):
 
 
 class DuelRoom(HealthRoom):
-    mode = RoomMode.duel
+    @staticmethod
+    def get_mode() -> RoomMode:
+        return RoomMode.duel
+
     player_count: int = 2
     players: list[DuelPlayer] = []
