@@ -1,4 +1,5 @@
 import uuid
+from abc import ABC, abstractmethod
 from datetime import datetime
 from enum import StrEnum
 
@@ -17,13 +18,22 @@ class RoomStatus(StrEnum):
     running = 'running'
 
 
-class BaseRoom(BaseModel):
+class BaseRoom(BaseModel, ABC):
     id: str = Field(alias='id_', default_factory=lambda: str(uuid.uuid4()))
-    mode: RoomMode
     map: str = 'world'
     status: RoomStatus = RoomStatus.waiting
     create_time: datetime = Field(default_factory=datetime.now)
     start_time: datetime | None = None
 
+    def __init__(self, **data):
+        if 'mode' not in data:
+            data['mode'] = self.get_mode()
+        super().__init__(**data)
+
+    @staticmethod
+    @abstractmethod
+    def get_mode() -> RoomMode:
+        pass
+
     class Config:
         allow_population_by_field_name = True
